*******************************************************************
* Calculation of poverty PPPs
*
* Program   : 511_cpd_US$_NIPA105.do
* Authors   : Angus Deaton, Princeton University
*             Olivier Dupriez, World Bank
* Version   : December 25, 2008
* Purpose   : Calculation of PPP conversion to US$ for CPD using NIPA 105 weights
*             This is done for "rhetoric" purpose only.
*
* This Stata program is part of the following collection of Stata [.do] files:

* 
* Preparation of data files:
*   00_data_reshape_102_105
*   00_data_reshape_102_105_ALL
*
* Calculation of PPPs (NIPA and survey weights):
*   01a_ppp_nipa_102
*   01b_ppp_nipa_105
*   01c_ppp_nipa_102_ALL
*   01d_ppp_nipa_105_ALL
*   02_cpd_index_surveys
*   03_super_index_surveys
*
* Calculation of PPPPs and US$ index- Option "14 unweighted poverty lines":
*   104_tornqvist_approximation_14plnw
*   105_poverty_indexes_cpd_14plnw
*   106_poverty_indexes_cpd_sterrs_14plnw
*   107_poverty_indexes_fisher_14plnw
*   108_poverty_indexes_fisher_sterrs_14plnw
*   109_poverty_indexes_tornqvist_14plnw
*   110_poverty_indexes_tornqvist_sterrs_14plnw
*   111_cpd_USD_14plnw
*   112_fisher_USD_14plnw
*   113_tornqvist_USD_14plnw
*
* Calculation of PPPPs and US$ index- Option "50 weighted poverty lines":
*   204_tornqvist_approximation_50plw
*   205_poverty_indexes_cpd_50plw
*   206_poverty_indexes_cpd_sterrs_50plw
*   207_poverty_indexes_fisher_50plw
*   208_poverty_indexes_fisher_sterrs_50plw
*   209_poverty_indexes_tornqvist_50plw
*   210_poverty_indexes_tornqvist_sterrs_50plw
*   211_cpd_USD_50plw
*   212_fisher_USD_50plw
*   213_tornqvist_USD_50plw
*
* Calculation of PPPPs and US$ index- Option "50 weighted and doubled poverty lines":
*   304_tornqvist_approximation_50plw2
*   305_poverty_indexes_cpd_50plw2
*   306_poverty_indexes_cpd_sterrs_50plw2
*   307_poverty_indexes_fisher_50plw2
*   308_poverty_indexes_fisher_sterrs_50plw2
*   309_poverty_indexes_tornqvist_50plw2
*   310_poverty_indexes_tornqvist_sterrs_50plw2
*   311_cpd_USD_50plw2
*   312_fisher_USD_50plw2
*   313_tornqvist_USD_50plw2
*
* Star system for conversion to US$ for estimates from national accounts:
*   411_cpd_USD_NIPA102
*   412_fisher_USD_NIPA102
*   413_tornqvist_USD_NIPA102
*   511_cpd_USD_NIPA105
*   512_fisher_USD_NIPA105
*   513_tornqvist_USD_NIPA105
*
* Estimation of PPPs by regression model for non-ICP or non-survey countries:
*   601_regressions_PPP_estimates
*
****************************************************************************

version 9.2
#delimit;
set logtype text;
clear;
set mem 200m;
set matsize 6700;
set more off;
cap log close; 
clear;

* >> Enter directories where datafiles are found, and calculations have to be saved;
local dirdata  = "C:\Users\Olivier\_P4_Final\P4_Input_Files";
local dircalc  = "C:\Users\Olivier\_P4_Final\P4_Calculations";
cd "`dirdata'";

* >> Enter number of basic headings to be used in calculations;

local ng=105;

* >> Enter list of countries to be included in the calculation;
global cns= "us in bd bt kh cn fj id la my mv mn np pk ph lk th vn bj bf bi cm cv td cd cg ci dj et ga gm 
gh gn ke ls mg mw ml mr ma mz ne ng rw sn sl za sz tz tg ug ar bo br co py pe am az kz kg tj ye";

global cns_1= "in bd bt kh cn fj id la my mv mn np pk ph lk th vn bj bf bi cm cv td cd cg ci dj et ga gm 
gh gn ke ls mg mw ml mr ma mz ne ng rw sn sl za sz tz tg ug ar bo br co py pe am az kz kg tj ye";

*We count the number of countries;
global nc=0;
foreach iso of global cns {;
    global nc=$nc+1;
};
local nc1=$nc-1;
display "Number of countries is: " $nc;

* >> Enter name and location of input and log files;
local icprice  = "`dirdata'\bh_icp_prices_`ng'_Final_with_OECD.dta";
log using "`dircalc'\PPPP_to_USD_CPD_NIPA105.smcl", replace;

* We generate a new data file with parities at basic heading level, all converted in a same currency (Indian Rp)   ;
* using CPD PPPs ;

* >> Select price variables to be used; 
use "`icprice'", replace;
keep p_us
     p_in p_bd p_bt p_kh p_cn p_fj p_id p_la p_my p_mv p_mn p_np p_pk p_ph p_lk p_th p_vn
     p_bj p_bf p_bi p_cm p_cv p_td p_cd p_cg p_ci p_dj p_et p_ga p_gm p_gh p_gn p_ke p_ls 
     p_mg p_mw p_ml p_mr p_ma p_mz p_ne p_ng p_rw p_sn p_sl p_za p_sz p_tz p_tg p_ug
     p_ar p_bo p_br p_co p_py p_pe p_am p_az p_kz p_kg p_tj p_ye;

* >> Edit this using the CPD NIPA 105 PPP estimates;
replace p_in=p_in/	1	;
replace p_bd=p_bd/	1.635	;
replace p_bt=p_bt/	1.16	;
replace p_kh=p_kh/	99.42	;
replace p_cn=p_cn/	0.265	;
replace p_fj=p_fj/	0.111	;
replace p_id=p_id/	270.517	;
replace p_la=p_la/	244.226	;
replace p_my=p_my/	0.136	;
replace p_mv=p_mv/	0.742	;
replace p_mn=p_mn/	33.536	;
replace p_np=p_np/	1.597	;
replace p_pk=p_pk/	1.315	;
replace p_ph=p_ph/	1.509	;
replace p_lk=p_lk/	2.498	;
replace p_th=p_th/	1.089	;
replace p_vn=p_vn/	379.202	;
replace p_bj=p_bj/	18.048	;
replace p_bf=p_bf/	15.895	;
replace p_bi=p_bi/	30.672	;
replace p_cm=p_cm/	19.154	;
replace p_cv=p_cv/	5.479	;
replace p_td=p_td/	23.702	;
replace p_cd=p_cd/	20.374	;
replace p_cg=p_cg/	24.56	;
replace p_ci=p_ci/	21.36	;
replace p_dj=p_dj/	7.072	;
replace p_et=p_et/	0.186	;
replace p_ga=p_ga/	30.04	;
replace p_gm=p_gm/	0.72	;
replace p_gh=p_gh/	315.234	;
replace p_gn=p_gn/	103.312	;
replace p_ke=p_ke/	2.255	;
replace p_ls=p_ls/	0.228	;
replace p_mg=p_mg/	52.444	;
replace p_mw=p_mw/	4.036	;
replace p_ml=p_ml/	19.178	;
replace p_mr=p_mr/	8.701	;
replace p_ma=p_ma/	0.38	;
replace p_mz=p_mz/	794.689	;
replace p_ne=p_ne/	17.876	;
replace p_ng=p_ng/	5.32	;
replace p_rw=p_rw/	15.475	;
replace p_sn=p_sn/	20.117	;
replace p_sl=p_sl/	97.032	;
replace p_za=p_za/	0.308	;
replace p_sz=p_sz/	0.253	;
replace p_tz=p_tz/	32.233	;
replace p_tg=p_tg/	19.18	;
replace p_ug=p_ug/	48.672	;
replace p_ar=p_ar/	0.091	;
replace p_bo=p_bo/	0.169	;
replace p_br=p_br/	0.109	;
replace p_co=p_co/	80.46	;
replace p_py=p_py/	140.545	;
replace p_pe=p_pe/	0.121	;
replace p_am=p_am/	11.031	;
replace p_az=p_az/	101.243	;
replace p_kz=p_kz/	3.847	;
replace p_kg=p_kg/	0.73	;
replace p_tj=p_tj/	0.051	;
replace p_ye=p_ye/	5.449	;

global cnb=1;
foreach iso of global cns {;
   ren p_`iso' p$cnb;
   gen lnp$cnb=log(p$cnb);
   mkmat lnp$cnb;
   global cnb=$cnb+1;
};

drop _all;

* We construct the X matrix for the CPD regressions;

matrix lnp=lnp1;
forvalues i=2(1)$nc {;
   matrix lnp=lnp\lnp`i';
   mat drop lnp`i';
};
mat drop lnp1;

matrix i1=J(`ng',1,1);
matrix i0=J(`ng',1,0);

forvalues w=1(1)$nc {;
   forvalues v=1(1)$nc {;
      if `v'==1 & `w'==1 {;
          matrix x`w'=i1;
      };
      if `v'==1 & `w'>1 {;
          matrix x`w'=i0;
      };
      if `v'>1 & `v'~=`w' {;
          matrix x`w'=x`w'\i0;
      };
      if `v'>1 & `v'==`w' {;
          matrix x`w'=x`w'\i1;
      };
   };
};
matrix x=x1;
forvalues i=2(1)$nc {;
   matrix x=x,x`i';
   mat drop x`i';
};
mat drop x1;

matrix bb=J(1,`ng'-1,0)\I(`ng'-1);
matrix aa=bb;
forvalues i=2(1)$nc {;
   matrix aa=aa\bb;
};
matrix x=x,aa;

* Build weight matrixes (these are national accounts weights);
drop _all;
global cno=1;
foreach iso of global cns {;
   use new_bh_nat_accounts_105.dta, clear;
   keep x_`iso';
   mkmat *, mat(wpov$cno);
   global cno=$cno+1;
};

* Calculate the CPD index;
matrix w=wpov1;
forvalues i=2(1)$nc {;
        matrix w=w\wpov`i';
};
matrix w=diag(w);
matrix aa=syminv(x'*w*x);
matrix b=aa*x'*w*lnp;
matrix tt=b[2..$nc,1]-J($nc-1,1,1)*b[1,1];
matrix torns_1=0\tt;
display "New CPD indexes";
mat list torns_1;

#delimit ;
matrix fis=J($nc-1,4,0);
local nc2=$nc-1;
forvalues i=1(1)`nc2' {;
   local j=`i'+1;
   matrix fis[`i',1]=exp(torns_1[`j',1]);
};

* Add weighting coefficients (population share among total population of 4,315,624,705);  
matrix pop = 
0.253632573	\
0.035517713	\
0.000147606	\
0.003233717	\
0.302273735	\
0.000191872	\
0.051106854	\
0.001312419	\
0.005944211	\
6.84251E-05	\
0.000591803	\
0.006278038	\
0.03609489	\
0.019595347	\
0.004557394	\
0.014598793	\
0.019256749	\
0.00196734	\
0.003228585	\
0.001821009	\
0.004123424	\
0.000117435	\
0.002350902	\
0.013611134	\
0.000836461	\
0.004306376	\
0.000186348	\
0.017418799	\
0.000299074	\
0.000374692	\
0.005221726	\
0.002086061	\
0.008248853	\
0.000458991	\
0.004319789	\
0.003064699	\
0.002690477	\
0.000686599	\
0.006984553	\
0.004757753	\
0.003073527	\
0.032754489	\
0.002139619	\
0.002727378	\
0.00129446	\
0.010865734	\
0.000262071	\
0.008915945	\
0.001445578	\
0.00670753	\
0.00897834	\
0.002127621	\
0.043291707	\
0.010414666	\
0.001366813	\
0.006319888	\
0.000699241	\
0.001944527	\
0.003509816	\
0.001191832	\
0.00151779	\
0.00488821	;

forvalues i=1(1)`nc1' {;
   matrix fis[`i',2]=pop[`i',1];
   matrix fis[`i',3]=fis[`i',1]*fis[`i',2];
};

mat list fis; 

* We calculate the weighted average of the ppp estimates to obtain the US$ ppp;
global pppusa=0;
forvalues i=1(1)`nc1' {;
    global pppusa=$pppusa+fis[`i',3];
};

* Display final result;
display "The weighted average of CPD PPPP estimates of [ref. currency] to US$ is: " $pppusa;

scalar p4=$pppusa;
scalar plus=(563.1/p4)*(12/365);

display "The international poverty line in US$ is: " plus " US$ per capita per day";

log close;

