***************************************************************************
* Calculation of poverty PPPs
*
* Program: 00_data_reshape_102_105.do
* Author : Changqing Sun; adapted by Olivier Dupriez (World Bank) 
* Date   : April 13, 2009
*
* Purpose: Impute consumption PPPs for non-benchmark countries.
*          This done by seemingly unrelated regression.
*
* Input  : An input data file was provided by Changqing Sun which contains the variables
*          needed to run the regressions. 
*
* This Stata program is part of the following collection of Stata [.do] files:
* 
* Preparation of data files:
*   00_data_reshape_102_105
*   00_data_reshape_102_105_ALL
*
* Calculation of PPPs (NIPA and survey weights):
*   01a_ppp_nipa_102
*   01b_ppp_nipa_105
*   01c_ppp_nipa_102_ALL
*   01d_ppp_nipa_105_ALL
*   02_cpd_index_surveys
*   03_super_index_surveys
*
* Calculation of PPPPs and US$ index- Option "14 unweighted poverty lines":
*   104_tornqvist_approximation_14plnw
*   105_poverty_indexes_cpd_14plnw
*   106_poverty_indexes_cpd_sterrs_14plnw
*   107_poverty_indexes_fisher_14plnw
*   108_poverty_indexes_fisher_sterrs_14plnw
*   109_poverty_indexes_tornqvist_14plnw
*   110_poverty_indexes_tornqvist_sterrs_14plnw
*   111_cpd_USD_14plnw
*   112_fisher_USD_14plnw
*   113_tornqvist_USD_14plnw
*
* Calculation of PPPPs and US$ index- Option "50 weighted poverty lines":
*   204_tornqvist_approximation_50plw
*   205_poverty_indexes_cpd_50plw
*   206_poverty_indexes_cpd_sterrs_50plw
*   207_poverty_indexes_fisher_50plw
*   208_poverty_indexes_fisher_sterrs_50plw
*   209_poverty_indexes_tornqvist_50plw
*   210_poverty_indexes_tornqvist_sterrs_50plw
*   211_cpd_USD_50plw
*   212_fisher_USD_50plw
*   213_tornqvist_USD_50plw
*
* Calculation of PPPPs and US$ index- Option "50 weighted and doubled poverty lines":
*   304_tornqvist_approximation_50plw2
*   305_poverty_indexes_cpd_50plw2
*   306_poverty_indexes_cpd_sterrs_50plw2
*   307_poverty_indexes_fisher_50plw2
*   308_poverty_indexes_fisher_sterrs_50plw2
*   309_poverty_indexes_tornqvist_50plw2
*   310_poverty_indexes_tornqvist_sterrs_50plw2
*   311_cpd_USD_50plw2
*   312_fisher_USD_50plw2
*   313_tornqvist_USD_50plw2
*
* Star system for conversion to US$ for estimates from national accounts:
*   411_cpd_USD_NIPA102
*   412_fisher_USD_NIPA102
*   413_tornqvist_USD_NIPA102
*   511_cpd_USD_NIPA105
*   512_fisher_USD_NIPA105
*   513_tornqvist_USD_NIPA105
*
* Estimation of PPPs by regression model for non-ICP or non-survey countries:
*   601_regressions_PPP_estimates
*
**************************************************************************** 

#delimit;
cap log close;
set more 1; 
program drop _all;
constraint drop _all;

log using "G:\_P4_Final\P4_Calculations\601_PPP_Imputations.smcl", replace;

use "G:\_P4_Final\P4_Input_Files\Data_for_PPP_Imputation.dta", clear;
gen flag2 = 0;
replace flag2 = 1 if icp==1 & code~="IND" & code~="ZWE" & code~="BDI"; 

gen source = 2 if icp==0 & gdpd_weo~=. & mer_weo~=.;
replace source = 1 if icp==0 & gdpd_wdi~=. & mer_dec~=.; 
replace gdpd = gdpd_wdi if source==1;
replace gdpd = gdpd_weo if source==2;
replace mer = mer_dec if source==1;
replace mer = mer_weo if source==2;
gen gdpl = gdpl_wdi if source==1;
replace gdpl = gdpl_weo if source==2;

replace mer=mer/44.1;
replace  ppp= ppp/14.66854167875;
replace cppp=cppp/15.60153979186;

gen consrup=.;
replace consrup = consl_wdi/mer if icp==0;

for new eap eca lac mna sas ssa oec noe: gen X = 0;
replace eap = 1 if region == "EAP";
replace eca = 1 if region == "ECA";
replace mna = 1 if region == "MNA";
replace lac = 1 if region == "LAC";
replace sas = 1 if region == "SAS";
replace ssa = 1 if region == "SSA";
replace oec = 1 if region == ".." & income=="OEC";
replace noe = 1 if region == ".." & income=="NOC";

replace pli=ppp/mer*100;
save "G:\_P4_Final\P4_Source_Files\_Misc\tempfile.dta", replace;


use "G:\_P4_Final\P4_Source_Files\_Misc\tempfile.dta", clear;
   gen cpli = cppp/mer*100;
   for var pli cpli gdpd im_wdi ex_wdi depratio \ new lpli lcpli lgdpd lim lex ldep: gen Y=ln(X);
   gen id=1 if code=="IND";
   sort id;
   list country in 1;
   for var lpli lcpli lgdpd lim lex ldep \ new ipli icpli igdpd iim iex idep: gen Y = X - X[1];
   for var ssa island landlock \ new gdpssa gdpisl gdplan: gen Y = X*lgdpd - X[1]*lgdpd[1];
   replace oec = oec - oec[1];
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock, noc)   
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island, noc) if flag2==1, isure;
   predict lplihat2, xb equation(#1);
   predict lcplihat2, xb equation(#2);
   predict lplire2, resi equation(#1);
   predict lcplire2, resi equation(#2);
   for new ppphat2 cppphat2 \ var lplihat2 lcplihat2: gen X = exp(Y)*mer;
   for new gdpphat2 consphat2 \ var ppphat2 cppphat2 \ var gdpd consd: gen X = Z/(Y/mer);
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock) 
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island) if flag2==1, isure;
   test [ipli]_cons [icpli]_cons;
   keep code country ppp cppp ppphat2 cppphat2;
   rename ppphat2 ippp;
   rename cppphat2 icppp;
   sort code;
save "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta", replace;


use "G:\_P4_Final\P4_Source_Files\_Misc\tempfile.dta", clear;
   gen cpli = c102/mer*100;
   for var pli cpli gdpd im_wdi ex_wdi depratio \ new lpli lcpli lgdpd lim lex ldep: gen Y=ln(X);
   gen id=1 if code=="IND";
   sort id;
   list country in 1;
   for var lpli lcpli lgdpd lim lex ldep \ new ipli icpli igdpd iim iex idep: gen Y = X - X[1];
   for var ssa island landlock \ new gdpssa gdpisl gdplan: gen Y = X*lgdpd - X[1]*lgdpd[1];
   replace oec = oec - oec[1];
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock, noc)   
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island, noc) if flag2==1, isure;
   predict lplihat2, xb equation(#1);
   predict lcplihat2, xb equation(#2);
   predict lplire2, resi equation(#1);
   predict lcplire2, resi equation(#2);
   for new ppphat2 cppphat2 \ var lplihat2 lcplihat2: gen X = exp(Y)*mer;
   for new gdpphat2 consphat2 \ var ppphat2 cppphat2 \ var gdpd consd: gen X = Z/(Y/mer);
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock) 
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island) if flag2==1, isure;
   test [ipli]_cons [icpli]_cons;
   keep code cppphat2;
   rename cppphat2 ic102;
   sort code;
   merge code using "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta"; 
   drop _merge;
   sort code;
save "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta", replace;


use "G:\_P4_Final\P4_Source_Files\_Misc\tempfile.dta", clear;
   gen cpli = f102/mer*100;
   for var pli cpli gdpd im_wdi ex_wdi depratio \ new lpli lcpli lgdpd lim lex ldep: gen Y=ln(X);
   gen id=1 if code=="IND";
   sort id;
   list country in 1;
   for var lpli lcpli lgdpd lim lex ldep \ new ipli icpli igdpd iim iex idep: gen Y = X - X[1];
   for var ssa island landlock \ new gdpssa gdpisl gdplan: gen Y = X*lgdpd - X[1]*lgdpd[1];
   replace oec = oec - oec[1];
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock, noc)   
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island, noc) if flag2==1, isure;
   predict lplihat2, xb equation(#1);
   predict lcplihat2, xb equation(#2);
   predict lplire2, resi equation(#1);
   predict lcplire2, resi equation(#2);
   for new ppphat2 cppphat2 \ var lplihat2 lcplihat2: gen X = exp(Y)*mer;
   for new gdpphat2 consphat2 \ var ppphat2 cppphat2 \ var gdpd consd: gen X = Z/(Y/mer);
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock) 
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island) if flag2==1, isure;
   test [ipli]_cons [icpli]_cons;
   keep code cppphat2;
   rename cppphat2 if102;
   sort code;
   merge code using "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta"; 
   drop _merge;
   sort code;
save "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta", replace;


use "G:\_P4_Final\P4_Source_Files\_Misc\tempfile.dta", clear;
   gen cpli = t102/mer*100;
   for var pli cpli gdpd im_wdi ex_wdi depratio \ new lpli lcpli lgdpd lim lex ldep: gen Y=ln(X);
   gen id=1 if code=="IND";
   sort id;
   list country in 1;
   for var lpli lcpli lgdpd lim lex ldep \ new ipli icpli igdpd iim iex idep: gen Y = X - X[1];
   for var ssa island landlock \ new gdpssa gdpisl gdplan: gen Y = X*lgdpd - X[1]*lgdpd[1];
   replace oec = oec - oec[1];
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock, noc)   
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island, noc) if flag2==1, isure;
   predict lplihat2, xb equation(#1);
   predict lcplihat2, xb equation(#2);
   predict lplire2, resi equation(#1);
   predict lcplire2, resi equation(#2);
   for new ppphat2 cppphat2 \ var lplihat2 lcplihat2: gen X = exp(Y)*mer;
   for new gdpphat2 consphat2 \ var ppphat2 cppphat2 \ var gdpd consd: gen X = Z/(Y/mer);
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock) 
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island) if flag2==1, isure;
   test [ipli]_cons [icpli]_cons;
   keep code cppphat2;
   rename cppphat2 it102;
   sort code;
   merge code using "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta"; 
   drop _merge;
   sort code;
save "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta", replace;


use "G:\_P4_Final\P4_Source_Files\_Misc\tempfile.dta", clear;
   gen cpli = c105/mer*100;
   for var pli cpli gdpd im_wdi ex_wdi depratio \ new lpli lcpli lgdpd lim lex ldep: gen Y=ln(X);
   gen id=1 if code=="IND";
   sort id;
   list country in 1;
   for var lpli lcpli lgdpd lim lex ldep \ new ipli icpli igdpd iim iex idep: gen Y = X - X[1];
   for var ssa island landlock \ new gdpssa gdpisl gdplan: gen Y = X*lgdpd - X[1]*lgdpd[1];
   replace oec = oec - oec[1];
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock, noc)   
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island, noc) if flag2==1, isure;
   predict lplihat2, xb equation(#1);
   predict lcplihat2, xb equation(#2);
   predict lplire2, resi equation(#1);
   predict lcplire2, resi equation(#2);
   for new ppphat2 cppphat2 \ var lplihat2 lcplihat2: gen X = exp(Y)*mer;
   for new gdpphat2 consphat2 \ var ppphat2 cppphat2 \ var gdpd consd: gen X = Z/(Y/mer);
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock) 
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island) if flag2==1, isure;
   test [ipli]_cons [icpli]_cons;
   keep code cppphat2;
   rename cppphat2 ic105;
   sort code;
   merge code using "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta"; 
   drop _merge;
   sort code;
save "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta", replace;


use "G:\_P4_Final\P4_Source_Files\_Misc\tempfile.dta", clear;
   gen cpli = f105/mer*100;
   for var pli cpli gdpd im_wdi ex_wdi depratio \ new lpli lcpli lgdpd lim lex ldep: gen Y=ln(X);
   gen id=1 if code=="IND";
   sort id;
   list country in 1;
   for var lpli lcpli lgdpd lim lex ldep \ new ipli icpli igdpd iim iex idep: gen Y = X - X[1];
   for var ssa island landlock \ new gdpssa gdpisl gdplan: gen Y = X*lgdpd - X[1]*lgdpd[1];
   replace oec = oec - oec[1];
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock, noc)   
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island, noc) if flag2==1, isure;
   predict lplihat2, xb equation(#1);
   predict lcplihat2, xb equation(#2);
   predict lplire2, resi equation(#1);
   predict lcplire2, resi equation(#2);
   for new ppphat2 cppphat2 \ var lplihat2 lcplihat2: gen X = exp(Y)*mer;
   for new gdpphat2 consphat2 \ var ppphat2 cppphat2 \ var gdpd consd: gen X = Z/(Y/mer);
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock) 
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island) if flag2==1, isure;
   test [ipli]_cons [icpli]_cons;
   keep code cppphat2;
   rename cppphat2 if105;
   sort code;
   merge code using "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta"; 
   drop _merge;
   sort code;
save "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta", replace;


use "G:\_P4_Final\P4_Source_Files\_Misc\tempfile.dta", clear;
   gen cpli = t105/mer*100;
   for var pli cpli gdpd im_wdi ex_wdi depratio \ new lpli lcpli lgdpd lim lex ldep: gen Y=ln(X);
   gen id=1 if code=="IND";
   sort id;
   list country in 1;
   for var lpli lcpli lgdpd lim lex ldep \ new ipli icpli igdpd iim iex idep: gen Y = X - X[1];
   for var ssa island landlock \ new gdpssa gdpisl gdplan: gen Y = X*lgdpd - X[1]*lgdpd[1];
   replace oec = oec - oec[1];
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock, noc)   
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island, noc) if flag2==1, isure;
   predict lplihat2, xb equation(#1);
   predict lcplihat2, xb equation(#2);
   predict lplire2, resi equation(#1);
   predict lcplire2, resi equation(#2);
   for new ppphat2 cppphat2 \ var lplihat2 lcplihat2: gen X = exp(Y)*mer;
   for new gdpphat2 consphat2 \ var ppphat2 cppphat2 \ var gdpd consd: gen X = Z/(Y/mer);
   sureg (ipli igdpd iex iim idep gdpisl gdpssa oec ssa island landlock) 
         (icpli igdpd idep gdpssa gdpisl gdplan ssa oec island) if flag2==1, isure;
   test [ipli]_cons [icpli]_cons;
   keep code cppphat2;
   rename cppphat2 it105;
   sort code;
   merge code using "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta"; 
   drop _merge;
   sort code;
   order code country ppp cppp ippp icppp ic102 if102 it102 ic105 if105 it105;
save "G:\_P4_Final\P4_Calculations\PPP_Imputed.dta", replace;

log close;
erase "G:\_P4_Final\P4_Source_Files\_Misc\tempfile.dta"
;

